@@ -8,6 +8,8 @@ import os, sys, re, types
 try: import yaml, yaml.constructor
 except ImportError: pass
 
+try: from types import StringTypes as str_types
+except ImportError: str_types = str, bytes # py3
 
 
 class OrderedDictYAMLLoader(yaml.SafeLoader):
@@ -72,7 +74,7 @@ class AttrDict(OrderedDict):
 
 	@classmethod
 	def from_yaml(cls, path_or_file, if_exists=False):
-		if isinstance(path_or_file, types.StringTypes):
+		if instance(path_or_file, str_types):
 			if if_exists and not os.path.exists(path_or_file): return cls()
 			with open(path_or_file) as src:
 				return cls(yaml.load(src, OrderedDictYAMLLoader))
